@@ -82,7 +82,8 @@ class Program(object):
                 self._json_next(dct, _event, parent)    
 
     def _dump_json(self, dct):
-        return dict([(name, variable.json()) for name, variable in dct.items()])
+        return dict([(name, variable.json() if hasattr(variable, 'json') else variable)\
+                     for name, variable in dct.items()])
 
     def json(self):
         dct = {}
@@ -130,6 +131,21 @@ class Logout(Event):
 class Signup(Event):
     pass
 
+class Addtocart(Event):
+    pass
+
+class Storeopens(Event):
+    pass
+
+class Storecloses(Event):
+    pass
+
+class Subscribe(Event):
+    pass
+
+class Unsubscribe(Event):
+    pass
+
 class On(Event):
     ARGS = ["date"]
     PROPERTIES = {
@@ -183,11 +199,11 @@ class Sms(Event):
     }
 
 class Email(Event):
-    ARGS = ["user", "subject", "html"]
+    ARGS = ["user", "subject", "body"]
     PROPERTIES = {
         "+user": "user",
         "+subject": "string",
-        "+html": "html",
+        "+body": "html",
         "subscription": "string"
     }
 
@@ -260,7 +276,7 @@ class Push(Script):
         assert self.extra["varpath"].endswith('[]'), "Can only push into :arrays"
         assert re.match(r'^[a-zA-Z_][a-zA-Z]', self.extra["varpath"]), "Invalid variable name. Must start with /^[a-zA-Z_][a-zA-Z]/"
 
-class With(Script):
+class With(Event):
     pass
 
 # ------------------------
@@ -361,11 +377,11 @@ class String(Script):
                     values[str(len(values))] = st.json()
                     string.append("{%d}" % (len(values)-1))
                 else:
-                    string.append(st.strip())
-            return dict(string=' '.join(string), values=values)
+                    string.append(st)
+            return dict(string=''.join(string).strip(), values=values)
 
         else:
-            return " ".join([d.strip() for d in self.datas])
+            return " ".join([d.strip() for d in self.datas]).strip()
 
 class Number(Script):
     def __init__(self, number):
@@ -402,6 +418,10 @@ class Expression(Script):
                 evals = [_d['expression']]
                 values = _d['values']
 
+            elif isinstance(expression, Number):
+                d = str(float(expression.number))
+                evals.append(d)
+
             elif hasattr(expression, 'json'):
                 d = expression.json()
                 if isinstance(d, dict):
