@@ -197,6 +197,18 @@ class Lexer(object):
         r'(at|on)'
         return t
 
+    def t_ADDTOCART(self, t):
+        r'(add to cart)'
+        return t
+
+    def t_STOREOPENS(self, t):
+        r'(store opens)'
+        return t
+
+    def t_STORECLOSES(self, t):
+        r'(store closes)'
+        return t
+
     @TOKEN(NAME)
     def t_ID(self, t):
         # check for reserved words
@@ -216,9 +228,11 @@ class Lexer(object):
         if t.value.endswith('%'):
             t.value = float(t.value[:-1]) / 100
         elif t.value.find('$') > -1:
-            t.value = float(t.value[1:])
+            float(t.value[1:]) # just to test it
+            t.value = t.value[1:]
         else:
-            t.value = float(t.value)
+            float(t.value) # just to test it
+            t.value = t.value
         return t
 
     def t_error(self,t):
