@@ -90,23 +90,21 @@ class Parser(object):
             p[1].append(p[2])
             p[0] = p[1]
 
-    def p_task_checkout(self, p):
+    def p_task_bfs(self, p):
         '''task : AFTER CHECKOUT suite EOF
-                | BEFORE CHECKOUT suite EOF'''
-        p[0] = ast.Checkout(parser=self, lineno=p.lineno(1), when=p[1], suite=p[3])
-
-    def p_task_after_login(self, p):
-        '''task : AFTER LOGIN suite EOF'''
-        p[0] = ast.Login(parser=self, lineno=p.lineno(1), when=p[1], suite=p[3])
-
-    def p_task_logout(self, p):
-        '''task : AFTER LOGOUT suite EOF
-                | BEFORE LOGOUT suite EOF'''
-        p[0] = ast.Logout(parser=self, lineno=p.lineno(1), when=p[1], suite=p[3])
-
-    def p_task_signup(self, p):
-        '''task : AFTER SIGNUP suite EOF'''
-        p[0] = ast.Signup(parser=self, lineno=p.lineno(1), when=p[1], suite=p[3])
+                | BEFORE CHECKOUT suite EOF
+                | AFTER ADDTOCART suite EOF
+                | BEFORE ADDTOCART suite EOF
+                | AFTER UNSUBSCRIBE suite EOF
+                | AFTER SUBSCRIBE suite EOF
+                | AFTER SIGNUP suite EOF
+                | AFTER LOGIN suite EOF
+                | AFTER LOGOUT suite EOF
+                | BEFORE LOGOUT suite EOF
+                | AFTER STOREOPENS suite EOF
+                | AFTER STORECLOSES suite EOF
+                | BEFORE STORECLOSES suite EOF'''
+        p[0] = getattr(ast, p[2].capitalize())(parser=self, lineno=p.lineno(1), when=p[1], suite=p[3])
 
     def p_periodically(self, p):
         '''periodically : HOURLY
@@ -390,9 +388,9 @@ class Parser(object):
                         varpath=ast.Varpath(p[4]), value=p[1])
 
     def p_stmt_with(self, p):
-        '''stmt : WITH VARPATH suite'''
+        '''stmt : WITH varpaths suite'''
         p[0] = ast.With(parser=self, lineno=p.lineno(1),
-                        varpath=ast.Varpath(p[2]), suite=p[3])
+                        varpath=ast.Varpath(varpath=p[2]), suite=p[3])
 
     # ------------------
     # Expressions
@@ -452,6 +450,24 @@ class Parser(object):
                                                     method="like",
                                                     other=p[3]))
 
+    def p_expression_isnotequal(self, p):
+        '''expression : varpaths IS NOT EQUAL TO variable'''
+        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+                                                    method="isnt",
+                                                    other=p[6]))
+
+    def p_expression_isequal(self, p):
+        '''expression : varpaths IS EQUAL TO variable'''
+        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+                                                    method="is",
+                                                    other=p[5]))
+
+    def p_expression_equals(self, p):
+        '''expression : varpaths EQUALS variable'''
+        p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
+                                                    method="is",
+                                                    other=p[3]))
+
     def p_expression_is(self, p):
         '''expression : varpaths IS expression'''
         p[0] = ast.Expression(expression=ast.Method(varpath=ast.Varpath(varpath=p[1]),
