@@ -36,14 +36,6 @@ VARIABLE_RESERVED_NAMES = [
     "layout"]
 
 KEYWORDS = [
-  # NEED TO IMPLEMENT!!!
-  # "of",
-  # "while",
-  # "unless",
-  # "start",
-  # "equals",
-  # "not",
-
   # if...else if...else
   "if",
   "else",
@@ -54,15 +46,6 @@ KEYWORDS = [
   "first",
   "last",
 
-  # Before | After Events
-  "login",
-  "logout",
-  "before",
-  "after",
-
-  # Events
-  "signup",
-
   # AGG's
   "largest",
   "newest",
@@ -87,6 +70,11 @@ KEYWORDS = [
   "like",
   "or",
   "to",
+  "before",
+  "after",
+  "equals",
+  "equal",
+  "not",
   
   # System
   "unset",
@@ -113,7 +101,14 @@ KEYWORDS = [
 ]
 
 EVENTS = [
-  # "purchase",
+  "storeopens",
+  "storecloses",
+  "unsubscribe",
+  "subscribe",
+  "addtocart",
+  "login",
+  "logout",
+  "signup",
   "tweet",
   "checkout",
   "reward",
@@ -122,4 +117,4 @@ EVENTS = [
   "dialog",
   "wait",
   "email",
-]
\ No newline at end of file
+]
